/**
 * This is the main PropBoeXbee program start point.
 */
#include <stdio.h>
#include <stdlib.h>
#include <sys/thread.h>
#include <propeller.h>

/* declare xbee here so we can use dprintf */
FILE *xbee;

/* this is a special version of dprintf that lets us do IO with xbee */
#define dprintf(p1,p2) fprintf(xbee,p1,p2)

#include "propboe.h"
#include "PropBoeServos.h"

/**
 * Main program function.
 */
int main(void)
{
    int mstime = (CLKFREQ/1000);
    int speed = 80;

    char cmdstr[2];
    int cmd;

    extern int StopNoPulse;
    // StopNoPulse = 0;

    xbee = fopen("SSER:9600,0,1", "r+");

    /* keep QuickStart TX quiet. */
    DIRA |= (1<<30);

    setvbuf(xbee, NULL, _IONBF, 0);    // no buffering stdin
    setvbuf(xbee, NULL, _IONBF, 0);   // no buffering stdout
    xbee->_flag |= _IOCOOKED;          // turn on echo 

    waitcnt(50*mstime+CNT);

    startServoThreads();
    botStop();
    botSpeed(0);

    for(;;) {

        extern int LeftServoSpeed;
        extern int RightServoSpeed;
        extern int LeftRotation;
        extern int RightRotation;

        waitcnt(CLKFREQ/5+CNT);

        dprintf("%c",0);

        dprintf("LR = %d ",LeftRotation);
        dprintf("RR = %d\n",RightRotation);
        dprintf("LS = %d ",LeftServoSpeed);
        dprintf("RS = %d\n",RightServoSpeed);
        dprintf("SPEED = %d\n",speed);

        dprintf("%c",'>');

        fgets(cmdstr, 2, xbee);
        cmd = cmdstr[0];
        if(!cmd) {
            continue;
        }

        dprintf(" cmd (%d)\n",cmd);
        StopNoPulse = 1; // no calibration unless told
        
        switch(cmd) {
            case '-':
                if(speed >= 10) speed -= 10;
                dprintf("speed- %d\n", speed);
                botSpeed(speed);
            break;
            case '+':
                if(speed <= 90) speed += 10;
                dprintf("speed+ %d\n", speed);
                botSpeed(speed);
            break;

            case 'C':
                botStop();
                StopNoPulse = 0;
                dprintf("calibrate\n", 0);
            break;

            case UP_ARROW: // fall through
            case 'f':
                botForward(speed);
                dprintf("forward %d\n", speed);
            break;
            case DN_ARROW: // fall through
            case 'b':
                botReverse(speed);
                dprintf("backward %d\n", speed);
            break;
            case LEFT_ARROW: // fall through
            case 'l':
                botLeftTurn(speed);
                dprintf("left  turn %d\n", speed);
            break;
            case RIGHT_ARROW: // fall through
            case 'r':
                botRightTurn(speed);
                dprintf("right turn %d\n", speed);
            break;
            case HOME_KEY: // fall through
            case 'L':
                botLeftSpin(speed);
                dprintf("left  spin %d\n", speed);
            break;
            case PAGE_UP: // fall through
            case 'R':
                botRightSpin(speed);
                dprintf("right spin %d\n", speed);
            break;
            case END_KEY: // fall through
            case 's':
                botStop();
                dprintf("stop\n",0);
            break;
        }
    }

    return 0;
}

